Deprecated `Axis.unit_data`
```````````````````````````

Use `Axis.units` (which has long existed) instead.

Only accept string-like for Categorical input
`````````````````````````````````````````````

Do not accept mixed string / float / int input, only
strings are valid categoricals.
